@@ -71,7 +71,11 @@ MainWindow::MainWindow(QWidget *parent)
     m_exitAnimationGroup->addAnimation(m_fadeOutAnimation);
     m_exitAnimationGroup->addAnimation(m_floatUpAnimation);
     connect(m_exitAnimationGroup, &QParallelAnimationGroup::finished,
+#ifdef Q_OS_MAC
+            this, &QWidget::hide);
+#else
             this, &QWidget::close);
+#endif
 
     GraphicsScene * scene = new GraphicsScene(this);
 
@@ -160,10 +164,6 @@ MainWindow::MainWindow(QWidget *parent)
     installResizeCapture(m_graphicsView->viewport());
     installResizeCapture(m_gv);
     installResizeCapture(m_gv->viewport());
-
-#ifdef Q_OS_MACOS
-    qApp->installEventFilter(this);
-#endif // Q_OS_MACOS
 }
 
 MainWindow::~MainWindow()
@@ -376,6 +376,10 @@ void MainWindow::mouseDoubleClickEvent(QMouseEvent *event)
         toggleMaximize();
         event->accept();
         break;
+    case Settings::DoubleClickBehavior::FullScreen:
+        toggleFullscreen();
+        event->accept();
+        break;
     case Settings::DoubleClickBehavior::Ignore:
         break;
     }
@@ -559,7 +563,7 @@ void MainWindow::centerWindow()
             Qt::LeftToRight,
             Qt::AlignCenter,
             this->size(),
-            qApp->screenAt(QCursor::pos())->geometry()
+            qApp->screenAt(QCursor::pos())->availableGeometry()
         )
     );
 }
@@ -657,19 +661,6 @@ QSize MainWindow::sizeHint() const
     return QSize(710, 530);
 }
 
-#ifdef Q_OS_MACOS
-bool MainWindow::eventFilter(QObject *obj, QEvent *event)
-{
-    Q_UNUSED(obj);
-    if (event->type() == QEvent::FileOpen) {
-        QFileOpenEvent *fileOpenEvent = static_cast<QFileOpenEvent *>(event);
-        showUrls({fileOpenEvent->url()});
-        return true;
-    }
-    return false;
-}
-#endif // Q_OS_MACOS
-
 void MainWindow::on_actionOpen_triggered()
 {
     QStringList picturesLocations = QStandardPaths::standardLocations(QStandardPaths::PicturesLocation);
